@@ -1,7 +1,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x03080200
+#define LIBXL_VERSION 0x03080300
 
 #ifdef _UNICODE
 
@@ -21,12 +21,14 @@
     #define xlBookLoadPartially xlBookLoadPartiallyW
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileW
     #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsW
+    #define xlBookLoadInfo xlBookLoadInfoW
     #define xlBookLoadRaw xlBookLoadRawW
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyW
     #define xlBookSaveRaw xlBookSaveRawW
     #define xlBookAddSheet xlBookAddSheetW
     #define xlBookInsertSheet xlBookInsertSheetW
     #define xlBookGetSheet xlBookGetSheetW
+    #define xlBookGetSheetName xlBookGetSheetNameW
     #define xlBookSheetType xlBookSheetTypeW
     #define xlBookMoveSheet xlBookMoveSheetW
     #define xlBookDelSheet xlBookDelSheetW
@@ -318,12 +320,14 @@
     #define xlBookLoadPartially xlBookLoadPartiallyA
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileA
     #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsA
+    #define xlBookLoadInfo xlBookLoadInfoA
     #define xlBookLoadRaw xlBookLoadRawA
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyA
     #define xlBookSaveRaw xlBookSaveRawA
     #define xlBookAddSheet xlBookAddSheetA
     #define xlBookInsertSheet xlBookInsertSheetA
     #define xlBookGetSheet xlBookGetSheetA
+    #define xlBookGetSheetName xlBookGetSheetNameA
     #define xlBookSheetType xlBookSheetTypeA
     #define xlBookMoveSheet xlBookMoveSheetA
     #define xlBookDelSheet xlBookDelSheetA
